<?php
declare(strict_types=1);

namespace App\Pay\Zhifuxpay\Impl;

use App\Entity\PayEntity;
use App\Pay\Base;
use App\Util\Http;
use App\Util\Str;
use GuzzleHttp\Exception\GuzzleException;
use Kernel\Exception\JSONException;

/**
 * Class Pay
 * @package App\Pay\Kvmpay\Impl
 */
class Pay extends Base implements \App\Pay\Pay
{

    /**
     * @return PayEntity
     * @throws JSONException|GuzzleException
     */
    public function trade(): PayEntity
    {
       
        if (!$this->config['url']) {
            throw new JSONException("请配置支付星接口地址");
        }

        if (!$this->config['merchantNum']) {
            throw new JSONException("请配置支付星商户号");
        }
        if (!$this->config['key']) {
            throw new JSONException("请配置支付星商户密钥");
        }
        //$this->code
        $hashKey = $this->config['key'];

        $param = array(
           "merchantNum" => $this->config['merchantNum'],
           "payType" => $this->code,
           "amount" => $this->amount,
           "orderNo" => $this->tradeNo,
           "notifyUrl" => $this->callbackUrl,
           "returnUrl" =>$this->returnUrl,
           "sign" => $sign,
           "returnType" => "json"
       );
        $param['sign'] = Signature::generateSignature($param, $hashKey);
        try {
            $request = Http::make()->post($this->config['url'], [
                "form_params" => $param
            ]);

            $contents = $request->getBody()->getContents();
            $json = json_decode($contents, true);

            if ($json['success'] != true) {
                throw new JSONException((string)$json['msg']);
            }

            $url = $json['data']['payUrl'];
        } catch (\Exception|\Error $e) {
            throw new JSONException("请求失败".$json['msg']);
        }

        $payEntity = new PayEntity();
        $payEntity->setType(self::TYPE_REDIRECT);
        $payEntity->setUrl($url);
        return $payEntity;
    }
}